<?php
/**
 * Este plugin insere um input que mostra os valores que podem ser selecionados enquanto o usurio digita.
 * Os valores so preenchidos previamente atravs de uma requisio ajax: a classe e mtodo que ser invocado  passado por parmetro no momento em que o desenvolvedor utiliza o componente.
 *
 * @package Smarty
 * @subpackage wf_plugins
 * @param array $params Array de parametros
 * - name: o nome que o componente ir receber.
 * - ajaxClass: classe ajax que ser utilizada para fazer a consulta.
 * - ajaxMethod: mtodo da classe que ser invocado para preencher a lista de opes.
 * - methodParam: Parmetro para o mtodo que ser invocado para preencher a lista de opes.
 * - idValue: (opcional) o id de um item previamente selecionado (no  visvel para o usurio).
 * - textValue: (opcional) o texto de um item inicialmente selecionado ( visvel para o usurio).
 * - minLength: (opcional) nmero mnimo de caracteres necessrios para que as opes apaream na lista.
 * - style: (opcional) estilo para o campo input
 * @param object &$smarty Instncia do objeto smarty em uso
 * @return string $output codigo que insere os select boxes.
 * @access public
 */
function smarty_function_wf_autocomplete_input($params, &$smarty)
{
	$requiredParams = array(
		'name',
		'ajaxClass',
		'ajaxMethod'
	);
	$defaultValues = array(
		'minLength'	=> 1,
		'style'		=> "width: 200px"
	);
	$extractParams = array(
		'name',
		'ajaxClass',
		'ajaxMethod',
		'methodParam',
		'minLength',
		'idValue',
		'textValue',
		'style'
	);

	/* verifica se todos os parmetros obrigatrios foram passados */
	foreach ($requiredParams as $required)
		if (!array_key_exists($required, $params) || (empty($params[$required])))
			$smarty->trigger_error("[wf_autocomplete_input] missing required parameter(s): $required", E_USER_ERROR);

	/* atribui valores default para os parmetros no passados */
	foreach ($defaultValues as $key => $value)
		if (!isset($params[$key]))
			$params[$key] = $value;

	/* extrai alguns parmetros da matriz de parmetros */
	foreach ($extractParams as $extract)
		$$extract = $params[$extract];

	/* parmetros extras so "acumulados" em uma nica varivel */
	$extraParams = array();
	foreach ($params as $key => $value_params)
		if (!in_array($key, $extractParams))
			$extraParams[$key] = $value_params;

	$name_input = 'input' . $name;
	$name_list	= 'list' . $name;
	$name_response = 'response' . $name;

	/* se parmetro for um array "joga" para o javascript como um objeto JSON */
	if (is_array($methodParam)){
		$methodParam = json_encode($methodParam);
	} else {
		$sep = "'"; // se no for um objeto passa parmetro entre aspas
	}

	/* Cria um objeto JSON com os parmetros opcionais utilizados pelo javascript */
	$extraParams = array ('idValue'		=> $idValue
						, 'textValue'	=> $textValue
						, 'minLength'	=> $minLength
	);
	$extraParams = json_encode($extraParams);

	$output = <<<EOF
	<input id="$name" name="$name" type="hidden"/>
	<input id="$name_input" name="$name_input" type="text" value="$textValue" style="$style" onfocus="checkDataLoaded('$name');" onblur="setTimeout('selectAutocompleteElement(\'$name\')', 500);"/>
	<span id="$name_response"></span>
	<div id="$name_list" class="autocomplete" style="display: none;"></div>
	<script>autocompleteSelect('$name', '$ajaxClass', '$ajaxMethod', $sep$methodParam$sep, $extraParams);</script>
EOF;
	return $output;
}
?>
